==> python-dateparser-0.7.6-1-any.pkg.tar.xz: usr/lib/python3.8/site-packages/dateparser/data/date_translation_data/kk.py <==
# -*- coding: utf-8 -*-
info = {
    "name": "kk",
    "date_order": "DMY",
    "january": [
        "қаңтар",
        "қаң"
    ],
    "february": [
        "ақпан",
        "ақп"
    ],
    "march": [
        "наурыз",
        "нау"
    ],
    "april": [
        "сәуір",
        "сәу"
    ],
    "may": [
        "мамыр",
        "мам"
    ],
    "june": [
        "маусым",
        "мау"
    ],
    "july": [
        "шілде",
        "шіл"
    ],
    "august": [
        "тамыз",
        "там"
    ],
    "september": [
        "қыркүйек",
        "қыр"
    ],
    "october": [
        "қазан",
        "қаз"
    ],
    "november": [
        "қараша",
        "қар"
    ],
    "december": [
        "желтоқсан",
        "жел"
    ],
    "monday": [
        "дүйсенбі",
        "дс"
    ],
    "tuesday": [
        "сейсенбі",
        "сс"
    ],
    "wednesday": [
        "сәрсенбі",
        "ср"
    ],
    "thursday": [
        "бейсенбі",
        "бс"
    ],
    "friday": [
        "жұма",
        "жм"
    ],
    "saturday": [
        "сенбі",
        "сб"
    ],
    "sunday": [
        "жексенбі",
        "жс"
    ],
    "am": [
        "am"
    ],
    "pm": [
        "pm"
    ],
    "year": [
        "жыл",
        "ж"
    ],
    "month": [
        "ай"
    ],
    "week": [
        "апта",
        "ап"
    ],
    "day": [
        "күн"
    ],
    "hour": [
        "сағат",
        "сағ"
    ],
    "minute": [
        "минут",
        "мин"
    ],
    "second": [
        "секунд",
        "с"
    ],
    "relative-type": {
        "1 year ago": [
            "былтырғы жыл"
        ],
        "0 year ago": [
            "биылғы жыл"
        ],
        "in 1 year": [
            "келесі жыл"
        ],
        "1 month ago": [
            "өткен ай"
        ],
        "0 month ago": [
            "осы ай"
        ],
        "in 1 month": [
            "келесі ай"
        ],
        "1 week ago": [
            "өткен апта"
        ],
        "0 week ago": [
            "осы апта"
        ],
        "in 1 week": [
            "келесі апта"
        ],
        "1 day ago": [
            "кеше"
        ],
        "0 day ago": [
            "бүгін"
        ],
        "in 1 day": [
            "ертең"
        ],
        "0 hour ago": [
            "осы сағат"
        ],
        "0 minute ago": [
            "осы минут"
        ],
        "0 second ago": [
            "қазір"
        ]
    },
    "relative-type-regex": {
        "in \\1 year": [
            "(\\d+) жылдан кейін",
            "(\\d+) ж кейін"
        ],
        "\\1 year ago": [
            "(\\d+) жыл бұрын",
            "(\\d+) ж бұрын"
        ],
        "in \\1 month": [
            "(\\d+) айдан кейін"
        ],
        "\\1 month ago": [
            "(\\d+) ай бұрын"
        ],
        "in \\1 week": [
            "(\\d+) аптадан кейін",
            "(\\d+) ап кейін"
        ],
        "\\1 week ago": [
            "(\\d+) апта бұрын",
            "(\\d+) ап бұрын"
        ],
        "in \\1 day": [
            "(\\d+) күннен кейін"
        ],
        "\\1 day ago": [
            "(\\d+) күн бұрын"
        ],
        "in \\1 hour": [
            "(\\d+) сағаттан кейін",
            "(\\d+) сағ кейін"
        ],
        "\\1 hour ago": [
            "(\\d+) сағат бұрын",
            "(\\d+) сағ бұрын"
        ],
        "in \\1 minute": [
            "(\\d+) минуттан кейін",
            "(\\d+) мин кейін"
        ],
        "\\1 minute ago": [
            "(\\d+) минут бұрын",
            "(\\d+) мин бұрын"
        ],
        "in \\1 second": [
            "(\\d+) секундтан кейін",
            "(\\d+) сек кейін"
        ],
        "\\1 second ago": [
            "(\\d+) секунд бұрын",
            "(\\d+) сек бұрын"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}

==> python-dateparser-1.1.1-1-any.pkg.tar.xz: usr/lib/python3.10/site-packages/dateparser/data/date_translation_data/kk.py <==
info = {
    "name": "kk",
    "date_order": "DMY",
    "january": [
        "қаң",
        "қаңтар"
    ],
    "february": [
        "ақп",
        "ақпан"
    ],
    "march": [
        "нау",
        "наурыз"
    ],
    "april": [
        "сәу",
        "сәуір"
    ],
    "may": [
        "мам",
        "мамыр"
    ],
    "june": [
        "мау",
        "маусым"
    ],
    "july": [
        "шіл",
        "шілде"
    ],
    "august": [
        "там",
        "тамыз"
    ],
    "september": [
        "қыр",
        "қыркүйек"
    ],
    "october": [
        "қаз",
        "қазан"
    ],
    "november": [
        "қар",
        "қараша"
    ],
    "december": [
        "жел",
        "желтоқсан"
    ],
    "monday": [
        "дс",
        "дүйсенбі"
    ],
    "tuesday": [
        "сейсенбі",
        "сс"
    ],
    "wednesday": [
        "ср",
        "сәрсенбі"
    ],
    "thursday": [
        "бейсенбі",
        "бс"
    ],
    "friday": [
        "жм",
        "жұма"
    ],
    "saturday": [
        "сб",
        "сенбі"
    ],
    "sunday": [
        "жексенбі",
        "жс"
    ],
    "am": [
        "am"
    ],
    "pm": [
        "pm"
    ],
    "year": [
        "ж",
        "жыл"
    ],
    "month": [
        "ай"
    ],
    "week": [
        "ап",
        "апта"
    ],
    "day": [
        "күн"
    ],
    "hour": [
        "сағ",
        "сағат"
    ],
    "minute": [
        "мин",
        "минут"
    ],
    "second": [
        "с",
        "секунд"
    ],
    "relative-type": {
        "0 day ago": [
            "бүгін"
        ],
        "0 hour ago": [
            "осы сағат"
        ],
        "0 minute ago": [
            "осы минут"
        ],
        "0 month ago": [
            "осы ай"
        ],
        "0 second ago": [
            "қазір"
        ],
        "0 week ago": [
            "осы апта"
        ],
        "0 year ago": [
            "биылғы жыл"
        ],
        "1 day ago": [
            "кеше"
        ],
        "1 month ago": [
            "өткен ай"
        ],
        "1 week ago": [
            "өткен апта"
        ],
        "1 year ago": [
            "былтырғы жыл"
        ],
        "in 1 day": [
            "ертең"
        ],
        "in 1 month": [
            "келесі ай"
        ],
        "in 1 week": [
            "келесі апта"
        ],
        "in 1 year": [
            "келесі жыл"
        ]
    },
    "relative-type-regex": {
        "\\1 day ago": [
            "(\\d+) күн бұрын"
        ],
        "\\1 hour ago": [
            "(\\d+) сағ бұрын",
            "(\\d+) сағат бұрын"
        ],
        "\\1 minute ago": [
            "(\\d+) мин бұрын",
            "(\\d+) минут бұрын"
        ],
        "\\1 month ago": [
            "(\\d+) ай бұрын"
        ],
        "\\1 second ago": [
            "(\\d+) сек бұрын",
            "(\\d+) секунд бұрын"
        ],
        "\\1 week ago": [
            "(\\d+) ап бұрын",
            "(\\d+) апта бұрын"
        ],
        "\\1 year ago": [
            "(\\d+) ж бұрын",
            "(\\d+) жыл бұрын"
        ],
        "in \\1 day": [
            "(\\d+) күннен кейін"
        ],
        "in \\1 hour": [
            "(\\d+) сағ кейін",
            "(\\d+) сағаттан кейін"
        ],
        "in \\1 minute": [
            "(\\d+) мин кейін",
            "(\\d+) минуттан кейін"
        ],
        "in \\1 month": [
            "(\\d+) айдан кейін"
        ],
        "in \\1 second": [
            "(\\d+) сек кейін",
            "(\\d+) секундтан кейін"
        ],
        "in \\1 week": [
            "(\\d+) ап кейін",
            "(\\d+) аптадан кейін"
        ],
        "in \\1 year": [
            "(\\d+) ж кейін",
            "(\\d+) жылдан кейін"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ]
}
